@@ -1,22 +1,25 @@
 package IO::All::String;
-use IO::All -Base;
+use strict;
+use warnings;
+use IO::All -base;
 use IO::String;
 
 const type => 'string';
 proxy 'string_ref';
 
 sub string {
+    my $self = shift;
     bless $self, __PACKAGE__;
     $self->_init;
 }
 
 sub open {
+    my $self = shift;
     $self->io_handle(IO::String->new);
     $self->set_binmode;
+    $self->is_open(1);
 }
 
-__DATA__
-
 =head1 NAME 
 
 IO::All::String - String IO Support for IO::All
@@ -29,10 +32,12 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
+Copyright (c) 2006. Ingy döt Net. All rights reserved.
+
 Copyright (c) 2004. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
@@ -41,3 +46,5 @@ under the same terms as Perl itself.
 See http://www.perl.com/perl/misc/Artistic.html
 
 =cut
+
+1;
