@@ -1,7 +1,10 @@
 package IO::All::Temp;
-use IO::All::File -Base;
+use strict;
+use warnings;
+use IO::All::File -base;
 
 sub temp {
+    my $self = shift;
     bless $self, __PACKAGE__;
     my $temp_file = IO::File::new_tmpfile()
       or $self->throw("Can't create temporary file");
@@ -12,8 +15,6 @@ sub temp {
     return $self;
 }
 
-__DATA__
-
 =head1 NAME 
 
 IO::All::Temp - Temporary File Support for IO::All
@@ -26,10 +27,12 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
+Copyright (c) 2006. Ingy döt Net. All rights reserved.
+
 Copyright (c) 2004. Brian Ingerson. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
@@ -38,3 +41,5 @@ under the same terms as Perl itself.
 See http://www.perl.com/perl/misc/Artistic.html
 
 =cut
+
+1;
